==> nextcloud-25.0.12p1.tgz: nextcloud/apps/systemtags/l10n/pl.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Nazwa etykiety jest pusta",
    "Update" : "Uaktualnij",
    "Create" : "Utwórz",
    "Select tag …" : "Wybierz etykietę…",
    "System tag %1$s added by the system" : "Etykieta systemowa %1$s dodana przez system",
    "Added system tag {systemtag}" : "Dodano etykietę systemową  {systemtag}",
    "Added system tag %1$s" : "Dodano etykietę systemową %1$s",
    "%1$s added system tag %2$s" : "%1$s dodał etykietę systemową %2$s",
    "{actor} added system tag {systemtag}" : "{actor} dodał etykietę systemową {systemtag}",
    "System tag %1$s removed by the system" : "Znacznik systemowy %1$s usunięty przez system",
    "Removed system tag {systemtag}" : "Usunięto etykietą systemową {systemtag}",
    "Removed system tag %1$s" : "Usunięto etykietę systemową %1$s",
    "%1$s removed system tag %2$s" : "%1$s usunął etykietę systemową %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} usunął etykietę systemową {systemtag}",
    "You created system tag %1$s" : "Utworzyłeś etykietę systemową %1$s",
    "You created system tag {systemtag}" : "Utworzyłeś etykietę systemową {systemtag}",
    "%1$s created system tag %2$s" : "%1$s utworzył etykietę systemową %2$s",
    "{actor} created system tag {systemtag}" : "{actor} utworzył etykietę systemową {systemtag}",
    "You deleted system tag %1$s" : "Skasowałeś etykietę systemową %1$s",
    "You deleted system tag {systemtag}" : "Usunąłeś etykietę systemową {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s usunął etykietę systemową %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} usunął etykietę systemową {systemtag}",
    "You updated system tag %2$s to %1$s" : "Zaktualizowałeś etykietę systemową %2$s do %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Zaktualizowałeś etykietę systemową {oldsystemtag} do {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s zaktualizował etykietę systemową %3$s do %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} zaktualizował etykietę systemową {oldsystemtag} do {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Etykieta systemowy %2$s została dodana do %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Etykieta systemowa {systemtag} została dodana do {file}",
    "You added system tag %2$s to %1$s" : "Dodałeś etykietę systemową %2$s do %1$s",
    "You added system tag {systemtag} to {file}" : "Dodałeś etykietę systemową {systemtag} do {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s dodał etykiete systemową %3$s do %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} dodał etykietę systemową {systemtag} do {file}",
    "System tag %2$s was removed from %1$s by the system" : "Etykieta systemowa %2$s została usunięta z %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "Etykieta systemowa {systemtag} została usunięta z {file}",
    "You removed system tag %2$s from %1$s" : "Usunąłeś etykietę systemową %2$s z %1$s",
    "You removed system tag {systemtag} from {file}" : "Usunąłeś etykietę systemową {systemtag} z {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s usunął etykietę systemową %3$s z %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} usunął etykietę systemową {systemtag} z {file}",
    "%s (restricted)" : "%s (ograniczony)",
    "%s (invisible)" : "%s (niewidoczny)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Etykieta systemowa</strong> dla pliku została zmieniona",
    "Tags" : "Etykiety",
    "All tagged %s …" : "Wszystkie oznaczone %s…",
    "tagged %s" : "oznaczone %s",
    "Collaborative tags" : "Wspólne etykiety",
    "Collaborative tagging functionality which shares tags among users." : "Wspólna funkcja przypisywania etykiet, która udostępnia etykiety użytkownikom.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Wspólna funkcja przypisywania etykiet, która udostępnia etykiety użytkownikom. Idealne dla zespołów.\n\t(Jeśli jesteś dostawcą instalacji dla wielu odbiorców, zaleca się dezaktywację tej aplikacji, ponieważ etykiety są udostępniane.)",
    "Failed to load tags" : "Nie udało się załadować etykiet",
    "This file has the tag {tag}" : "Ten plik posiada etykietę {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Ten plik posiada etykiety {firstTags} i {lastTag}",
    "No tags found" : "Nie znaleziono etykiet",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Wspólne etykietowanie jest dostępne dla wszystkich użytkowników. Ograniczone etykiety są widoczne dla użytkowników, ale nie mogą być przez nich przypisane. Etykiety niewidoczne są natomiast przeznaczone do użytku wewnętrznego, ponieważ użytkownicy nie mogą ich zobaczyć ani przypisać.",
    "Create a new tag" : "Utwórz nową etykietę",
    "Name" : "Nazwa",
    "Public" : "Publiczne",
    "Restricted" : "Ograniczone",
    "Invisible" : "Niewidoczne",
    "Delete" : "Usuń",
    "Reset" : "Reset",
    "No files in here" : "Brak plików",
    "No entries found in this folder" : "Brak wpisów w tym katalogu",
    "Size" : "Rozmiar",
    "Modified" : "Modyfikacja",
    "Tagged files" : "Oznaczone pliki",
    "Select tags to filter by" : "Wybierz etykiety do filtrowania",
    "Please select tags to filter by" : "Wybierz etykiety do filtrowania",
    "No files found for the selected tags" : "Nie znaleziono plików dla wybranych etykiet"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-26.0.11p1.tgz: nextcloud/apps/systemtags/l10n/pl.js <==
OC.L10N.register(
    "systemtags",
    {
    "System tag %1$s added by the system" : "Etykieta systemowa %1$s dodana przez system",
    "Added system tag {systemtag}" : "Dodano etykietę systemową  {systemtag}",
    "Added system tag %1$s" : "Dodano etykietę systemową %1$s",
    "%1$s added system tag %2$s" : "%1$s dodał etykietę systemową %2$s",
    "{actor} added system tag {systemtag}" : "{actor} dodał etykietę systemową {systemtag}",
    "System tag %1$s removed by the system" : "Znacznik systemowy %1$s usunięty przez system",
    "Removed system tag {systemtag}" : "Usunięto etykietą systemową {systemtag}",
    "Removed system tag %1$s" : "Usunięto etykietę systemową %1$s",
    "%1$s removed system tag %2$s" : "%1$s usunął etykietę systemową %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} usunął etykietę systemową {systemtag}",
    "You created system tag %1$s" : "Utworzyłeś etykietę systemową %1$s",
    "You created system tag {systemtag}" : "Utworzyłeś etykietę systemową {systemtag}",
    "%1$s created system tag %2$s" : "%1$s utworzył etykietę systemową %2$s",
    "{actor} created system tag {systemtag}" : "{actor} utworzył etykietę systemową {systemtag}",
    "You deleted system tag %1$s" : "Skasowałeś etykietę systemową %1$s",
    "You deleted system tag {systemtag}" : "Usunąłeś etykietę systemową {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s usunął etykietę systemową %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} usunął etykietę systemową {systemtag}",
    "You updated system tag %2$s to %1$s" : "Zaktualizowałeś etykietę systemową %2$s do %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Zaktualizowałeś etykietę systemową {oldsystemtag} do {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s zaktualizował etykietę systemową %3$s do %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} zaktualizował etykietę systemową {oldsystemtag} do {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Etykieta systemowy %2$s została dodana do %1$s",
    "System tag {systemtag} was added to {file} by the system" : "Etykieta systemowa {systemtag} została dodana do {file}",
    "You added system tag %2$s to %1$s" : "Dodałeś etykietę systemową %2$s do %1$s",
    "You added system tag {systemtag} to {file}" : "Dodałeś etykietę systemową {systemtag} do {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s dodał etykiete systemową %3$s do %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} dodał etykietę systemową {systemtag} do {file}",
    "System tag %2$s was removed from %1$s by the system" : "Etykieta systemowa %2$s została usunięta z %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "Etykieta systemowa {systemtag} została usunięta z {file}",
    "You removed system tag %2$s from %1$s" : "Usunąłeś etykietę systemową %2$s z %1$s",
    "You removed system tag {systemtag} from {file}" : "Usunąłeś etykietę systemową {systemtag} z {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s usunął etykietę systemową %3$s z %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} usunął etykietę systemową {systemtag} z {file}",
    "%s (restricted)" : "%s (ograniczony)",
    "%s (invisible)" : "%s (niewidoczny)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Etykieta systemowa</strong> dla pliku została zmieniona",
    "Tags" : "Etykiety",
    "All tagged %s …" : "Wszystkie oznaczone %s…",
    "tagged %s" : "oznaczone %s",
    "Collaborative tags" : "Wspólne etykiety",
    "Collaborative tagging functionality which shares tags among users." : "Wspólna funkcja przypisywania etykiet, która udostępnia etykiety użytkownikom.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Wspólna funkcja przypisywania etykiet, która udostępnia etykiety użytkownikom. Idealne dla zespołów.\n\t(Jeśli jesteś dostawcą instalacji dla wielu odbiorców, zaleca się dezaktywację tej aplikacji, ponieważ etykiety są udostępniane.)",
    "Create" : "Utwórz",
    "Update" : "Uaktualnij",
    "Delete" : "Usuń",
    "Reset" : "Reset",
    "Loading …" : "Wczytywanie…",
    "Public" : "Publiczne",
    "Restricted" : "Ograniczone",
    "Invisible" : "Niewidoczne",
    "Failed to load tags" : "Nie udało się załadować etykiet",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Wspólne etykietowanie jest dostępne dla wszystkich użytkowników. Ograniczone etykiety są widoczne dla użytkowników, ale nie mogą być przez nich przypisane. Etykiety niewidoczne są natomiast przeznaczone do użytku wewnętrznego, ponieważ użytkownicy nie mogą ich zobaczyć ani przypisać.",
    "This file has the tag {tag}" : "Ten plik posiada etykietę {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Ten plik posiada etykiety {firstTags} i {lastTag}",
    "No tags found" : "Nie znaleziono etykiet",
    "No files in here" : "Brak plików",
    "No entries found in this folder" : "Brak wpisów w tym katalogu",
    "Name" : "Nazwa",
    "Size" : "Rozmiar",
    "Modified" : "Modyfikacja",
    "Tag name is empty" : "Nazwa etykiety jest pusta",
    "Select tag …" : "Wybierz etykietę…",
    "Tagged files" : "Oznaczone pliki",
    "Select tags to filter by" : "Wybierz etykiety do filtrowania",
    "Please select tags to filter by" : "Wybierz etykiety do filtrowania",
    "No files found for the selected tags" : "Nie znaleziono plików dla wybranych etykiet",
    "Create a new tag" : "Utwórz nową etykietę"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
